AstroPhot Demo
==============

Go to the `AstroPhot Demo <https://astrophotdemo.streamlit.app/>`_ to see a live demo of AstroPhot in action.

In the demo you can upload your own FITS file and try fitting it with AstroPhot.
Add models and tweak the parameters until they seem reasonably good by eye, then
run the ``Optimize`` button to fit the model to the data. The demo is hosted on
Streamlit sharing and is free to use. Since the demo runs on the free version of
Streamlit, it may be slow to run all the functions (especially plotting), but it
will give you a sense of how AstroPhot works.
